/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 08375
 |                  NATIONAL YOUTH SURVEY (1976): WAVE 1
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 08375-0001-statasetup.do)
 |
 **************************************************************************/

set mem 7m  /* Allocating 7 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "National Youth Survey (1976): Wave 1, Dataset 0001"

#delimit ;
label define V5        1 "Anglo" 2 "Black" 3 "Chicano" 4 "American Indian"
                       5 "Asian" 6 "Other" ;
label define V6        1 "Male" 2 "Female" ;
label define V7        1 "Single" 2 "Married" 3 "Divorced" 4 "Separated"
                       5 "Other" ;
label define V8        1 "Father" 2 "Stepfather" 3 "Foster father" 4 "Mother"
                       5 "Stepmother" 6 "Foster mother" 7 "Other relative"
                       8 "Other" ;
label define V9        1 "19 or under" 2 "20-29" 3 "30-39" 4 "40-49"
                       5 "50-59" 6 "60-69" 7 "70 or older" ;
label define V10       1 "19 or under" 2 "20-29" 3 "30-39" 4 "40-49"
                       5 "50-59" 6 "60-69" 7 "70 or older" 8 "Not applicable" ;
label define V11       1 "Post-grad degree" 2 "Completed college"
                       3 "Some college" 4 "High school/GED"
                       5 "Some high school" 6 "Grade school"
                       7 "Some grade school" ;
label define V12       1 "Post-grad degree" 2 "Completed college"
                       3 "Some college" 4 "High school/GED"
                       5 "Some high school" 6 "Grade school"
                       7 "Some grade school" ;
label define V13       1 "Father" 2 "Stepfather" 3 "Foster father" 4 "Mother"
                       5 "Stepmother" 6 "Foster mother" 7 "Other relative"
                       8 "Other" 9 "No wage earner" ;
label define V14       1 "Employed" 2 "Unemployed" 3 "Retired/disabled"
                       4 "Student" 5 "Housewife" 6 "Other" ;
label define V15       8 "Not applicable" 9 "Uncodable" ;
label define V17       1 "Employed" 2 "Unemployed" 3 "Retired/disabled"
                       4 "Student" 5 "Housewife" 6 "Other" ;
label define V18       8 "Not applicable" 9 "Uncodable" ;
label define V19       1 "$6,000 or less" 2 "$6,001-10,000"
                       3 "$10,001-14,000" 4 "$14,001-18,000"
                       5 "$18,001-22,000" 6 "$22,001-26,000"
                       7 "$26,001-30,000" 8 "$30,001-34,000"
                       9 "$34,001-38,000" 10 "$38,001 or more" ;
label define V20       1 "No" 2 "Yes" ;
label define V21       9 "9 youth or more" ;
label define V22       0 "None" ;
label define V23       1 "No" 2 "Yes" ;
label define V24       1 "No" 2 "Yes" ;
label define V25       1 "No" 2 "Yes" ;
label define V26       1 "No" 2 "Yes" ;
label define V27       1 "No" 2 "Yes" ;
label define V28       1 "No" 2 "Yes" ;
label define V29       1 "No" 2 "Yes" ;
label define V30       1 "No" 2 "Yes" ;
label define V31       1 "No" 2 "Yes" ;
label define V32       1 "No" 2 "Yes" ;
label define V33       1 "No" 2 "Yes" ;
label define V34       1 "No" 2 "Yes" ;
label define V35       1 "No" 2 "Yes" ;
label define V36       1 "No" 2 "Yes" ;
label define V38       1 "No" 2 "Yes" ;
label define V40       1 "No" 2 "Yes" ;
label define V41       1 "No" 2 "Yes" ;
label define V42       1 "No" 2 "Yes" ;
label define V43       1 "No" 2 "Yes" ;
label define V44       1 "No" 2 "Yes" ;
label define V45       1 "No" 2 "Yes" ;
label define V46       1 "Single fam house" 2 "Multiple fam house"
                       3 "Apt w/priv bath" 4 "Apt w/shared bath"
                       5 "Mobile trail/home" 6 "Hotel/motel" 7 "Other" ;
label define V47       1 "Less than 1 yr" 2 "1-2 years" 3 "3-4 years"
                       4 "More than 4 yrs" ;
label define V48       1 "Not a prob" 2 "Somewhat of prob" 3 "Big prob" ;
label define V49       1 "Not a prob" 2 "Somewhat of prob" 3 "Big prob" ;
label define V50       1 "Not a prob" 2 "Somewhat of prob" 3 "Big prob" ;
label define V51       1 "Not a prob" 2 "Somewhat of prob" 3 "Big prob" ;
label define V52       1 "Not a prob" 2 "Somewhat of prob" 3 "Big prob" ;
label define V53       1 "Not a prob" 2 "Somewhat of prob" 3 "Big prob" ;
label define V54       1 "Not a prob" 2 "Somewhat of prob" 3 "Big prob" ;
label define V55       1 "No" 2 "Yes" ;
label define V56       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V57       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V58       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V59       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V60       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V61       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V62       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V63       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V64       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V67       1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V68       1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V69       1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V70       1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V71       1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V72       1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V73       1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V74       1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V75       1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V76       1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V77       1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V78       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V79       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V80       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V81       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V82       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V83       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V84       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V85       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V86       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V87       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V88       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V89       1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V90       1 "No" 2 "Yes" 3 "Don't know" ;
label define V91       1 "None of them" 2 "Few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V92       1 "None of them" 2 "Few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V93       1 "None of them" 2 "Few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V94       1 "None of them" 2 "Few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V95       1 "None of them" 2 "Few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V96       1 "None of them" 2 "Few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V97       1 "None of them" 2 "Few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V98       1 "None of them" 2 "Few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V99       1 "None of them" 2 "Few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V100      1 "No" 2 "Yes" ;
label define V101      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V102      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V103      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V104      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V105      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V106      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V107      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V108      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V109      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V110      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V111      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V112      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V113      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V114      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V115      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V116      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V117      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V118      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V119      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V120      1 "Not wrong at all" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V121      1 "Definitely no" 2 "Probably no" 3 "Probably yes"
                       4 "Definitely yes" ;
label define V122      1 "Definitely no" 2 "Probably no" 3 "Probably yes"
                       4 "Definitely yes" ;
label define V123      1 "Definitely no" 2 "Probably no" 3 "Probably yes"
                       4 "Definitely yes" ;
label define V124      1 "Definitely no" 2 "Probably no" 3 "Probably yes"
                       4 "Definitely yes" ;
label define V125      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V126      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V127      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V128      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V129      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V130      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V131      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V132      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V133      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V134      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V135      1 "Non-inductive" 2 "Inductive" ;
label define V136      1 "Non-inductive" 2 "Inductive" ;
label define V137      1 "Non-inductive" 2 "Inductive" ;
label define V138      1 "Non-inductive" 2 "Inductive" ;
label define V139      1 "Non-inductive" 2 "Inductive" ;
label define V140      1 "Non-inductive" 2 "Inductive" ;
label define V141      1 "Non-inductive" 2 "Semi-inductive" 3 "Inductive" ;
label define V142      1 "Non-inductive" 2 "Semi-inductive" 3 "Inductive" ;
label define V143      1 "No" 2 "Yes" ;
label define V144      1 "Income question" ;
label define V145      1 "Sexual questions" ;
label define V149      1 "Q. about time w/kids" ;
label define V150      1 "Q. about discipline" ;
label define V151      1 "Q. about affection" ;
label define V152      1 "Q. about communicating" ;
label define V153      1 "Q. about religion" ;
label define V154      1 "Other" ;
label define V155      1 "Good" 2 "Poor" ;
label define V156      1 "Not at all anxious" 2 "Somewhat anxious"
                       3 "Very anxious" ;
label define V157      1 "No" 2 "Yes" ;
label define V158      1 "Very low" 2 "Below average" 3 "Average"
                       4 "Above average" 5 "Very high" ;
label define V159      1 "Diff w/language" ;
label define V160      1 "Diff w/ questions" ;
label define V161      1 "Interruptions" ;
label define V162      1 "Temp breakoff" ;
label define V163      1 "Breakoff" ;
label define V164      1 "Other" ;
label define V165      1 "Relaxed" 2 "Tense" 3 "Other" ;
label define V166      1 "No" 2 "Yes" ;
label define V167      1 "Male" 2 "Female" ;
label define V168      1 "Anglo" 2 "Black" 3 "Chicano" 4 "American Indian"
                       5 "Asian" 6 "Other" ;
label define V170      17 "not in school" 18 "other" ;
label define V171      1 "Mostly F's" 2 "Mostly D's" 3 "Mostly C's"
                       4 "Mostly B's" 5 "Mostly A's" ;
label define V172      1 "No" 2 "Yes" ;
label define V173      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V174      0 "Less than once wk" ;
label define V175      0 "Less than once a wk" ;
label define V176      1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V177      1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V178      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V179      0 "Less than once a wk" ;
label define V180      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V181      1 "No" 2 "Yes" ;
label define V182      0 "Less than once a wk" ;
label define V183      0 "Less than once a wk" ;
label define V184      1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V185      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V186      1 "No" 2 "Yes" ;
label define V187      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V188      0 "Less than once a wk" ;
label define V189      0 "Less than once a wk" ;
label define V190      1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V191      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V192      1 "No" 2 "Yes" ;
label define V193      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V194      0 "Less than once a wk" ;
label define V195      0 "Less than once a wk" ;
label define V196      1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V197      1 "Athlete" 2 "Activities member" 3 "Social type"
                       4 "Good student" 5 "Average student"
                       6 "None of the above" 7 "Other" ;
label define V198      1 "No" 2 "Yes" ;
label define V199      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V200      0 "Less than once a wk" ;
label define V201      0 "Less than once a wk" ;
label define V202      1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V203      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V204      1 "No" 2 "Yes" ;
label define V205      1 "Not important" 2 "Not too important"
                       3 "Somewhat important" 4 "Pretty important"
                       5 "Very important" ;
label define V206      1 "Part-time" 2 "Full-time" ;
label define V207      1 "No" 2 "Yes" ;
label define V208      0 "Less than once a wk" ;
label define V209      0 "Less than once a wk" ;
label define V210      1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V211      1 "Not important at All'" 2 "Not too Important"
                       3 "Somewhat Important" 4 "Pretty Important"
                       5 "Very Important" ;
label define V212      1 "Very little" 2 "Not too much" 3 "Some"
                       4 "Quite a bit" 5 "A great deal" ;
label define V213      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V214      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V215      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V217      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V218      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V219      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V220      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V221      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V222      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V223      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V224      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V225      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V226      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V227      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V228      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V229      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V230      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V231      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V232      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V233      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V234      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V235      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V236      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V237      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V238      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V239      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V240      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V241      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V242      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V243      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V244      1 "Not well" 3 "O.K." 5 "Very well" ;
label define V245      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V246      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V247      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V248      1 "Not important" 3 "Somewhat important"
                       5 "Very important" ;
label define V249      1 "Poor" 2 "Fair" 3 "Good" ;
label define V250      1 "Poor" 2 "Fair" 3 "Good" ;
label define V251      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V252      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V253      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V254      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V255      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V256      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V257      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V258      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V259      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V260      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V261      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V262      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V263      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V264      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V265      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V266      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V267      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V268      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V269      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V270      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V271      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V272      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V273      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V274      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V275      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V276      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V277      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V278      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V279      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V280      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V281      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V282      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V283      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V284      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V285      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V286      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V287      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V288      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V289      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V290      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V291      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V292      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V293      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V294      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V295      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V296      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V297      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V298      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V299      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V300      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V301      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V302      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V303      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V304      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V305      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V306      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V307      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V308      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V309      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V310      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V311      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V312      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V313      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V314      1 "Strongly disagree" 2 "Disagree" 3 "Neither"
                       4 "Agree" 5 "Strongly agree" ;
label define V315      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V316      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V317      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V318      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V319      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V320      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V321      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V322      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V323      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V324      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V325      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V326      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V327      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V328      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V329      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V330      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V331      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V332      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V333      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V334      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V335      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V336      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V337      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V338      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V339      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V340      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V341      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V342      1 "Strongly approve" 2 "Approve" 3 "Neither"
                       4 "Disapprove" 5 "Strongly disapprove" ;
label define V343      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V344      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V345      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V346      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V347      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V348      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V349      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V350      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V351      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V352      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V353      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V354      1 "Almost never" 2 "Sometimes" 3 "Often"
                       4 "Almost always" ;
label define V355      1 "Mother" 2 "Father" 3 "Both the same" ;
label define V356      1 "Not wrong" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V357      1 "Not wrong" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V358      1 "Not wrong" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V359      1 "Not wrong" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V360      1 "Not wrong" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V361      1 "Not wrong" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V362      1 "Not wrong" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V363      1 "Not wrong" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V364      1 "Not wrong" 2 "A little bit wrong" 3 "Wrong"
                       4 "Very wrong" ;
label define V365      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V366      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V367      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V368      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V369      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V370      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V371      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V372      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V373      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V374      1 "None of them" 2 "Very few of them" 3 "Some of them"
                       4 "Most of them" 5 "All of them" ;
label define V375      1 "No" 2 "Don't know" 3 "Yes" ;
label define V376      1 "No" 2 "Don't know" 3 "Yes" ;
label define V377      1 "No" 2 "Don't know" 3 "Yes" ;
label define V379      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V381      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V383      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V385      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V387      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V389      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V391      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V393      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V395      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V397      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V399      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V401      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V403      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V405      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V407      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V409      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V411      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V413      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V415      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V417      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V419      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V421      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V423      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V425      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V427      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V429      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V431      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V433      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V435      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V437      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V439      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V441      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V443      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V445      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V447      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V449      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V451      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V453      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V455      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V457      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V459      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V461      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V463      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V465      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V467      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V468      0 "None" ;
label define V469      0 "None" ;
label define V470      0 "None" ;
label define V471      0 "None" ;
label define V472      0 "None" ;
label define V473      0 "None" ;
label define V474      0 "None" ;
label define V475      0 "None" ;
label define V476      0 "None" ;
label define V477      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V478      1 "less than 1 yr ago" 2 "1-2 yrs ago"
                       3 "More than 2 yrs ago" ;
label define V479      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V480      1 "less than 1 yr ago" 2 "1-2 years ago"
                       3 "More than 2 yrs ago" ;
label define V481      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V482      1 "less than 1 yr ago" 2 "1-2 yrs ago"
                       3 "More than 2 yrs ago" ;
label define V483      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V484      1 "less than 1 yr ago" 2 "1-2 yrs ago"
                       3 "More than 2 yrs ago" ;
label define V485      1 "No" 2 "Yes" ;
label define V486      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V487      1 "less than 1 yr ago" 2 "1-2 yrs ago"
                       3 "More than 2 yrs ago" ;
label define V488      1 "No" 2 "Yes" ;
label define V489      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V490      1 "less than 1 yr ago" 2 "1-2 yrs ago"
                       3 "More than 2 yrs ago" ;
label define V491      1 "Sniffing" 2 "Injection" 3 "Combination of 1 & 2"
                       4 "Other" ;
label define V492      1 "Never" 2 "Once/twice yr" 3 "Once every 2-3 mos"
                       4 "Once a month" 5 "Once every 2-3 wks" 6 "Once a wk"
                       7 "2 to 3 times/wk" 8 "Once a day"
                       9 "2 to 3 times/day" ;
label define V493      1 "less than 1 yr ago" 2 "1-2 yrs ago"
                       3 "More than 2 yrs ago" ;
label define V494      1 "Sniffing" 2 "Injection" 3 "Combination of 1 & 2"
                       4 "Other" ;
label define V495      1 "No" 2 "Yes" ;
label define V496      1 "Drugs" ;
label define V497      1 "Sex" ;
label define V501      1 "Friends" ;
label define V502      1 "Drugs/alcohol" ;
label define V503      1 "Family" ;
label define V504      1 "Activities" ;
label define V505      1 "School" ;
label define V506      1 "Other" ;
label define V507      1 "Good understanding" 2 "Poor understanding" ;
label define V508      1 "Not at all anxious" 2 "Somewhat anxious"
                       3 "Very anxious" ;
label define V509      1 "No" 2 "Yes" ;
label define V510      1 "Very low" 2 "Below average" 3 "Average"
                       4 "Above average" 5 "Very high" ;
label define V511      1 "Diff w/language" ;
label define V512      1 "Diff w/questions" ;
label define V513      1 "Interruptions" ;
label define V514      1 "Temp breakoff" ;
label define V515      1 "Breakoff" ;
label define V516      1 "Other" ;
label define V517      1 "Relaxed" 2 "Tense" 3 "Other" ;
label define V518      1 "No" 2 "Yes" ;
label define V519      0 "Does not live in SMSA" 1 "Lives in SMSA" ;
label define V520      1 "City of SMSA" 2 "City of urban area"
                       3 "City of SMSA urban area" 4 "Other inc place"
                       5 "Not incorporated" ;
label define V521      0 "Under 200" 1 "200-499" 2 "500-999" 3 "1,000-1,499"
                       4 "1,500-1,999" 5 "2,000-2,499" 6 "2,500-4,999"
                       7 "5,000-9,999" 8 "10,000-19,999" 9 "20,000-24,999"
                       10 "25,000-49,999" 11 "50,000-99,999"
                       12 "100,000-249,999" 13 "250,000-499,999"
                       14 "500,000-999,999" 15 "1,000,000 or more" ;
label define V522      1 "Urban" 2 "Suburban" 3 "Rural" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace V5 = . if (V5 == 9)
replace V6 = . if (V6 == 9)
replace V7 = . if (V7 == 9)
replace V8 = . if (V8 == 9)
replace V9 = . if (V9 == 9)
replace V10 = . if (V10 == 8)
replace V11 = . if (V11 == 9)
replace V12 = . if (V12 == 9)
replace V14 = . if (V14 == 9)
replace V15 = . if (V15 == 8)
replace V16 = . if (V16 == 99)
replace V17 = . if (V17 == 9)
replace V18 = . if (V18 == 8)
replace V19 = . if (V19 == 99)
replace V20 = . if (V20 == 9)
replace V22 = . if (V22 == 9)
replace V23 = . if (V23 == 9)
replace V24 = . if (V24 == 9)
replace V25 = . if (V25 == 9)
replace V26 = . if (V26 == 9)
replace V27 = . if (V27 == 9)
replace V28 = . if (V28 == 9)
replace V29 = . if (V29 == 9)
replace V30 = . if (V30 == 9)
replace V31 = . if (V31 == 9)
replace V32 = . if (V32 == 9)
replace V33 = . if (V33 == 9)
replace V34 = . if (V34 == 9)
replace V35 = . if (V35 == 9)
replace V36 = . if (V36 == 9)
replace V37 = . if (V37 == 99)
replace V38 = . if (V38 == 9)
replace V39 = . if (V39 == 99)
replace V40 = . if (V40 == 9)
replace V41 = . if (V41 == 9)
replace V42 = . if (V42 == 9)
replace V43 = . if (V43 == 9)
replace V44 = . if (V44 == 9)
replace V45 = . if (V45 == 9)
replace V46 = . if (V46 == 9)
replace V47 = . if (V47 == 9)
replace V48 = . if (V48 == 9)
replace V49 = . if (V49 == 9)
replace V50 = . if (V50 == 9)
replace V51 = . if (V51 == 9)
replace V52 = . if (V52 == 9)
replace V53 = . if (V53 == 9)
replace V54 = . if (V54 == 9)
replace V55 = . if (V55 == 9)
replace V56 = . if (V56 == 9)
replace V57 = . if (V57 == 9)
replace V58 = . if (V58 == 9)
replace V59 = . if (V59 == 9)
replace V60 = . if (V60 == 9)
replace V61 = . if (V61 == 9)
replace V62 = . if (V62 == 9)
replace V63 = . if (V63 == 9)
replace V64 = . if (V64 == 9)
replace V65 = . if (V65 == 9999)
replace V66 = . if (V66 == 99)
replace V67 = . if (V67 == 9)
replace V68 = . if (V68 == 9)
replace V69 = . if (V69 == 9)
replace V70 = . if (V70 == 9)
replace V71 = . if (V71 == 9)
replace V72 = . if (V72 == 9)
replace V73 = . if (V73 == 9)
replace V74 = . if (V74 == 9)
replace V75 = . if (V75 == 9)
replace V76 = . if (V76 == 9)
replace V77 = . if (V77 == 9)
replace V78 = . if (V78 == 9)
replace V79 = . if (V79 == 9)
replace V80 = . if (V80 == 9)
replace V81 = . if (V81 == 9)
replace V82 = . if (V82 == 9)
replace V83 = . if (V83 == 9)
replace V84 = . if (V84 == 9)
replace V85 = . if (V85 == 9)
replace V86 = . if (V86 == 9)
replace V87 = . if (V87 == 9)
replace V88 = . if (V88 == 9)
replace V89 = . if (V89 == 9)
replace V90 = . if (V90 == 9)
replace V91 = . if (V91 == 9)
replace V92 = . if (V92 == 9)
replace V93 = . if (V93 == 9)
replace V94 = . if (V94 == 9)
replace V95 = . if (V95 == 9)
replace V96 = . if (V96 == 9)
replace V97 = . if (V97 == 9)
replace V98 = . if (V98 == 9)
replace V99 = . if (V99 == 9)
replace V100 = . if (V100 == 9)
replace V101 = . if (V101 == 9)
replace V102 = . if (V102 == 9)
replace V103 = . if (V103 == 9)
replace V104 = . if (V104 == 9)
replace V105 = . if (V105 == 9)
replace V106 = . if (V106 == 9)
replace V107 = . if (V107 == 9)
replace V108 = . if (V108 == 9)
replace V109 = . if (V109 == 9)
replace V110 = . if (V110 == 9)
replace V111 = . if (V111 == 9)
replace V112 = . if (V112 == 9)
replace V113 = . if (V113 == 9)
replace V114 = . if (V114 == 9)
replace V115 = . if (V115 == 9)
replace V116 = . if (V116 == 9)
replace V117 = . if (V117 == 9)
replace V118 = . if (V118 == 9)
replace V119 = . if (V119 == 9)
replace V120 = . if (V120 == 9)
replace V121 = . if (V121 == 9)
replace V122 = . if (V122 == 9)
replace V123 = . if (V123 == 9)
replace V124 = . if (V124 == 9)
replace V125 = . if (V125 == 9)
replace V126 = . if (V126 == 9)
replace V127 = . if (V127 == 9)
replace V128 = . if (V128 == 9)
replace V129 = . if (V129 == 9)
replace V130 = . if (V130 == 9)
replace V131 = . if (V131 == 9)
replace V132 = . if (V132 == 9)
replace V133 = . if (V133 == 9)
replace V134 = . if (V134 == 9)
replace V135 = . if (V135 == 9)
replace V136 = . if (V136 == 9)
replace V137 = . if (V137 == 9)
replace V138 = . if (V138 == 9)
replace V139 = . if (V139 == 9)
replace V140 = . if (V140 == 9)
replace V141 = . if (V141 == 9)
replace V142 = . if (V142 == 9)
replace V143 = . if (V143 == 9)
replace V144 = . if (V144 == 9)
replace V145 = . if (V145 == 9)
replace V146 = . if (V146 == 999)
replace V147 = . if (V147 == 999)
replace V148 = . if (V148 == 999)
replace V149 = . if (V149 == 9)
replace V150 = . if (V150 == 9)
replace V151 = . if (V151 == 9)
replace V152 = . if (V152 == 9)
replace V153 = . if (V153 == 9)
replace V154 = . if (V154 == 9)
replace V155 = . if (V155 == 9)
replace V156 = . if (V156 == 9)
replace V157 = . if (V157 == 9)
replace V158 = . if (V158 == 9)
replace V159 = . if (V159 == 9)
replace V160 = . if (V160 == 9)
replace V161 = . if (V161 == 9)
replace V162 = . if (V162 == 9)
replace V163 = . if (V163 == 9)
replace V164 = . if (V164 == 9)
replace V165 = . if (V165 == 9)
replace V166 = . if (V166 == 9)
replace V167 = . if (V167 == 9)
replace V169 = . if (V169 == 99)
replace V170 = . if (V170 == 0 | V170 == 99)
replace V171 = . if (V171 == 9)
replace V172 = . if (V172 == 9)
replace V173 = . if (V173 == 9)
replace V174 = . if (V174 == 9)
replace V175 = . if (V175 == 9)
replace V176 = . if (V176 == 9)
replace V177 = . if (V177 == 9)
replace V178 = . if (V178 == 9)
replace V179 = . if (V179 == 9)
replace V180 = . if (V180 == 9)
replace V181 = . if (V181 == 9)
replace V182 = . if (V182 == 9)
replace V183 = . if (V183 == 9)
replace V184 = . if (V184 == 9)
replace V185 = . if (V185 == 9)
replace V186 = . if (V186 == 9)
replace V187 = . if (V187 == 9)
replace V188 = . if (V188 == 9)
replace V189 = . if (V189 == 9)
replace V190 = . if (V190 == 9)
replace V191 = . if (V191 == 9)
replace V192 = . if (V192 == 9)
replace V193 = . if (V193 == 9)
replace V194 = . if (V194 == 9)
replace V195 = . if (V195 == 9)
replace V196 = . if (V196 == 9)
replace V198 = . if (V198 == 9)
replace V199 = . if (V199 == 9)
replace V200 = . if (V200 == 9)
replace V201 = . if (V201 == 9)
replace V202 = . if (V202 == 9)
replace V203 = . if (V203 == 9)
replace V204 = . if (V204 == 9)
replace V205 = . if (V205 == 9)
replace V206 = . if (V206 == 9)
replace V207 = . if (V207 == 9)
replace V208 = . if (V208 == 9)
replace V209 = . if (V209 == 9)
replace V210 = . if (V210 == 9)
replace V211 = . if (V211 == 99)
replace V212 = . if (V212 == 9)
replace V213 = . if (V213 == 9)
replace V214 = . if (V214 == 9)
replace V215 = . if (V215 == 9)
replace V216 = . if (V216 == 99)
replace V217 = . if (V217 == 9)
replace V218 = . if (V218 == 9)
replace V219 = . if (V219 == 9)
replace V220 = . if (V220 == 9)
replace V221 = . if (V221 == 9)
replace V222 = . if (V222 == 9)
replace V223 = . if (V223 == 9)
replace V224 = . if (V224 == 9)
replace V225 = . if (V225 == 9)
replace V226 = . if (V226 == 9)
replace V227 = . if (V227 == 9)
replace V228 = . if (V228 == 9)
replace V229 = . if (V229 == 9)
replace V230 = . if (V230 == 9)
replace V231 = . if (V231 == 9)
replace V232 = . if (V232 == 9)
replace V233 = . if (V233 == 9)
replace V234 = . if (V234 == 9)
replace V235 = . if (V235 == 9)
replace V236 = . if (V236 == 9)
replace V237 = . if (V237 == 9)
replace V238 = . if (V238 == 9)
replace V239 = . if (V239 == 9)
replace V240 = . if (V240 == 9)
replace V241 = . if (V241 == 9)
replace V242 = . if (V242 == 9)
replace V243 = . if (V243 == 9)
replace V244 = . if (V244 == 9)
replace V245 = . if (V245 == 9)
replace V246 = . if (V246 == 9)
replace V247 = . if (V247 == 9)
replace V248 = . if (V248 == 9)
replace V249 = . if (V249 == 9)
replace V250 = . if (V250 == 9)
replace V251 = . if (V251 == 9)
replace V252 = . if (V252 == 9)
replace V253 = . if (V253 == 9)
replace V254 = . if (V254 == 9)
replace V255 = . if (V255 == 9)
replace V256 = . if (V256 == 9)
replace V257 = . if (V257 == 9)
replace V258 = . if (V258 == 9)
replace V259 = . if (V259 == 9)
replace V260 = . if (V260 == 9)
replace V261 = . if (V261 == 9)
replace V262 = . if (V262 == 9)
replace V263 = . if (V263 == 9)
replace V264 = . if (V264 == 9)
replace V265 = . if (V265 == 9)
replace V266 = . if (V266 == 9)
replace V267 = . if (V267 == 9)
replace V268 = . if (V268 == 9)
replace V269 = . if (V269 == 9)
replace V270 = . if (V270 == 9)
replace V271 = . if (V271 == 9)
replace V272 = . if (V272 == 9)
replace V273 = . if (V273 == 9)
replace V274 = . if (V274 == 9)
replace V275 = . if (V275 == 9)
replace V276 = . if (V276 == 9)
replace V277 = . if (V277 == 9)
replace V278 = . if (V278 == 9)
replace V279 = . if (V279 == 9)
replace V280 = . if (V280 == 9)
replace V281 = . if (V281 == 9)
replace V282 = . if (V282 == 9)
replace V283 = . if (V283 == 9)
replace V284 = . if (V284 == 9)
replace V285 = . if (V285 == 9)
replace V286 = . if (V286 == 9)
replace V287 = . if (V287 == 9)
replace V288 = . if (V288 == 9)
replace V289 = . if (V289 == 9)
replace V290 = . if (V290 == 9)
replace V291 = . if (V291 == 9)
replace V292 = . if (V292 == 9)
replace V293 = . if (V293 == 9)
replace V294 = . if (V294 == 9)
replace V295 = . if (V295 == 9)
replace V296 = . if (V296 == 9)
replace V297 = . if (V297 == 9)
replace V298 = . if (V298 == 9)
replace V299 = . if (V299 == 9)
replace V300 = . if (V300 == 9)
replace V301 = . if (V301 == 9)
replace V302 = . if (V302 == 9)
replace V303 = . if (V303 == 9)
replace V304 = . if (V304 == 9)
replace V305 = . if (V305 == 9)
replace V306 = . if (V306 == 9)
replace V307 = . if (V307 == 9)
replace V308 = . if (V308 == 9)
replace V309 = . if (V309 == 9)
replace V310 = . if (V310 == 9)
replace V311 = . if (V311 == 9)
replace V312 = . if (V312 == 9)
replace V313 = . if (V313 == 9)
replace V314 = . if (V314 == 9)
replace V315 = . if (V315 == 9)
replace V316 = . if (V316 == 9)
replace V317 = . if (V317 == 9)
replace V318 = . if (V318 == 9)
replace V319 = . if (V319 == 9)
replace V320 = . if (V320 == 9)
replace V321 = . if (V321 == 9)
replace V322 = . if (V322 == 9)
replace V323 = . if (V323 == 9)
replace V324 = . if (V324 == 9)
replace V325 = . if (V325 == 9)
replace V326 = . if (V326 == 9)
replace V327 = . if (V327 == 9)
replace V328 = . if (V328 == 9)
replace V329 = . if (V329 == 9)
replace V330 = . if (V330 == 9)
replace V331 = . if (V331 == 9)
replace V332 = . if (V332 == 9)
replace V333 = . if (V333 == 9)
replace V334 = . if (V334 == 9)
replace V335 = . if (V335 == 9)
replace V336 = . if (V336 == 9)
replace V337 = . if (V337 == 9)
replace V338 = . if (V338 == 9)
replace V339 = . if (V339 == 9)
replace V340 = . if (V340 == 9)
replace V341 = . if (V341 == 9)
replace V342 = . if (V342 == 9)
replace V343 = . if (V343 == 9)
replace V344 = . if (V344 == 9)
replace V345 = . if (V345 == 9)
replace V346 = . if (V346 == 9)
replace V347 = . if (V347 == 9)
replace V348 = . if (V348 == 9)
replace V349 = . if (V349 == 9)
replace V350 = . if (V350 == 9)
replace V351 = . if (V351 == 9)
replace V352 = . if (V352 == 9)
replace V353 = . if (V353 == 9)
replace V354 = . if (V354 == 9)
replace V355 = . if (V355 == 9)
replace V356 = . if (V356 == 9)
replace V357 = . if (V357 == 9)
replace V358 = . if (V358 == 9)
replace V359 = . if (V359 == 9)
replace V360 = . if (V360 == 9)
replace V361 = . if (V361 == 9)
replace V362 = . if (V362 == 9)
replace V363 = . if (V363 == 9)
replace V364 = . if (V364 == 9)
replace V365 = . if (V365 == 9)
replace V366 = . if (V366 == 9)
replace V367 = . if (V367 == 9)
replace V368 = . if (V368 == 9)
replace V369 = . if (V369 == 9)
replace V370 = . if (V370 == 9)
replace V371 = . if (V371 == 9)
replace V372 = . if (V372 == 9)
replace V373 = . if (V373 == 9)
replace V376 = . if (V376 == 9)
replace V377 = . if (V377 == 9)
replace V378 = . if (V378 == 999)
replace V380 = . if (V380 == 999)
replace V382 = . if (V382 == 999)
replace V384 = . if (V384 == 999)
replace V386 = . if (V386 == 999)
replace V388 = . if (V388 == 999)
replace V390 = . if (V390 == 999)
replace V392 = . if (V392 == 999)
replace V394 = . if (V394 == 999)
replace V396 = . if (V396 == 999)
replace V398 = . if (V398 == 999)
replace V400 = . if (V400 == 999)
replace V402 = . if (V402 == 999)
replace V404 = . if (V404 == 999)
replace V406 = . if (V406 == 999)
replace V408 = . if (V408 == 999)
replace V410 = . if (V410 == 999)
replace V412 = . if (V412 == 999)
replace V414 = . if (V414 == 999)
replace V416 = . if (V416 == 999)
replace V418 = . if (V418 == 999)
replace V420 = . if (V420 == 999)
replace V422 = . if (V422 == 999)
replace V424 = . if (V424 == 999)
replace V426 = . if (V426 == 999)
replace V428 = . if (V428 == 999)
replace V430 = . if (V430 == 999)
replace V432 = . if (V432 == 999)
replace V434 = . if (V434 == 999)
replace V436 = . if (V436 == 999)
replace V438 = . if (V438 == 999)
replace V440 = . if (V440 == 999)
replace V442 = . if (V442 == 999)
replace V444 = . if (V444 == 999)
replace V446 = . if (V446 == 999)
replace V448 = . if (V448 == 999)
replace V450 = . if (V450 == 999)
replace V452 = . if (V452 == 999)
replace V454 = . if (V454 == 999)
replace V456 = . if (V456 == 999)
replace V458 = . if (V458 == 999)
replace V460 = . if (V460 == 999)
replace V462 = . if (V462 == 999)
replace V464 = . if (V464 == 999)
replace V466 = . if (V466 == 999)
replace V468 = . if (V468 == 999)
replace V469 = . if (V469 == 999)
replace V470 = . if (V470 == 999)
replace V471 = . if (V471 == 999)
replace V472 = . if (V472 == 999)
replace V473 = . if (V473 == 999)
replace V474 = . if (V474 == 999)
replace V475 = . if (V475 == 999)
replace V476 = . if (V476 == 999)
replace V478 = . if (V478 == 9)
replace V480 = . if (V480 == 9)
replace V482 = . if (V482 == 9)
replace V484 = . if (V484 == 9)
replace V485 = . if (V485 == 9)
replace V487 = . if (V487 == 9)
replace V488 = . if (V488 == 9)
replace V490 = . if (V490 == 9)
replace V491 = . if (V491 == 4)
replace V493 = . if (V493 == 9)
replace V494 = . if (V494 == 9)
replace V495 = . if (V495 == 9)
replace V496 = . if (V496 == 9)
replace V497 = . if (V497 == 9)
replace V498 = . if (V498 == 999)
replace V499 = . if (V499 == 999)
replace V500 = . if (V500 == 999)
replace V501 = . if (V501 == 9)
replace V502 = . if (V502 == 9)
replace V503 = . if (V503 == 9)
replace V504 = . if (V504 == 9)
replace V505 = . if (V505 == 9)
replace V506 = . if (V506 == 1)
replace V507 = . if (V507 == 9)
replace V508 = . if (V508 == 9)
replace V509 = . if (V509 == 9)
replace V510 = . if (V510 == 9)
replace V511 = . if (V511 == 9)
replace V512 = . if (V512 == 9)
replace V513 = . if (V513 == 9)
replace V514 = . if (V514 == 9)
replace V515 = . if (V515 == 9)
replace V516 = . if (V516 == 1)
replace V518 = . if (V518 == 9)
replace V519 = . if (V519 == 9)
replace V520 = . if (V520 == 9)
replace V521 = . if (V521 == 99)
replace V522 = . if (V522 == 9)


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

